Clean up old USE_* and RELEASE.md notes.
This commit is contained in:
@@ -2,12 +2,6 @@
|
|||||||
|
|
||||||
We have attempted to document known bugs and limitations - in particular the [HIP Kernel Language](docs/markdown/hip_kernel_language.md) document uses the phrase "Under Development", and the [HIP Runtime API bug list](http://gpuopen-professionalcompute-tools.github.io/HIP/bug.html) lists known bugs.
|
We have attempted to document known bugs and limitations - in particular the [HIP Kernel Language](docs/markdown/hip_kernel_language.md) document uses the phrase "Under Development", and the [HIP Runtime API bug list](http://gpuopen-professionalcompute-tools.github.io/HIP/bug.html) lists known bugs.
|
||||||
|
|
||||||
Upcoming:
|
|
||||||
- Stability: Enforce periodic host synchronization to reclaim resources if the application has launched a large
|
|
||||||
number of commands (>1K) without synchronizing.
|
|
||||||
- Register keyword now silently ignored on HCC (previously would emit warning).
|
|
||||||
- Doc updates: Add some more frequently asked questions to FAQ, fix TOC in some files, review.
|
|
||||||
- Cookbook.
|
|
||||||
|
|
||||||
===================================================================================================
|
===================================================================================================
|
||||||
|
|
||||||
|
|||||||
@@ -28,7 +28,6 @@ THE SOFTWARE.
|
|||||||
#ifndef HIP_INCLUDE_HIP_HCC_DETAIL_HOST_DEFINES_H
|
#ifndef HIP_INCLUDE_HIP_HCC_DETAIL_HOST_DEFINES_H
|
||||||
#define HIP_INCLUDE_HIP_HCC_DETAIL_HOST_DEFINES_H
|
#define HIP_INCLUDE_HIP_HCC_DETAIL_HOST_DEFINES_H
|
||||||
|
|
||||||
#define USE_PROMOTE_FREE_HCC 1
|
|
||||||
|
|
||||||
// Add guard to Generic Grid Launch method
|
// Add guard to Generic Grid Launch method
|
||||||
#ifndef GENERIC_GRID_LAUNCH
|
#ifndef GENERIC_GRID_LAUNCH
|
||||||
@@ -61,11 +60,7 @@ THE SOFTWARE.
|
|||||||
*/
|
*/
|
||||||
// _restrict is supported by the compiler
|
// _restrict is supported by the compiler
|
||||||
#define __shared__ tile_static
|
#define __shared__ tile_static
|
||||||
#if USE_PROMOTE_FREE_HCC==1
|
|
||||||
#define __constant__ __attribute__((hc))
|
#define __constant__ __attribute__((hc))
|
||||||
#else
|
|
||||||
#define __constant__ ADDRESS_SPACE_1
|
|
||||||
#endif
|
|
||||||
|
|
||||||
#else
|
#else
|
||||||
// Non-HCC compiler
|
// Non-HCC compiler
|
||||||
|
|||||||
@@ -48,9 +48,6 @@ THE SOFTWARE.
|
|||||||
#include "env.h"
|
#include "env.h"
|
||||||
|
|
||||||
|
|
||||||
// needs HCC change for hc::no_scope
|
|
||||||
#define USE_NO_SCOPE 1
|
|
||||||
|
|
||||||
//=================================================================================================
|
//=================================================================================================
|
||||||
//Global variables:
|
//Global variables:
|
||||||
//=================================================================================================
|
//=================================================================================================
|
||||||
|
|||||||
@@ -32,7 +32,6 @@ THE SOFTWARE.
|
|||||||
|
|
||||||
#endif
|
#endif
|
||||||
|
|
||||||
#define USE_AV_COPY (__hcc_workweek__ >= 16351)
|
|
||||||
|
|
||||||
size_t Nbytes = 0;
|
size_t Nbytes = 0;
|
||||||
|
|
||||||
@@ -410,21 +409,13 @@ void thread_noise_generator(int iters, size_t numBuffers, Dir addDir, Dir remove
|
|||||||
|
|
||||||
if (addDir == Up) {
|
if (addDir == Up) {
|
||||||
for (char *p = basePtr; p<basePtr + maxSize; p+=bufferSize) {
|
for (char *p = basePtr; p<basePtr + maxSize; p+=bufferSize) {
|
||||||
#if USE_AV_COPY
|
|
||||||
hc::AmPointerInfo info(p, p, bufferSize, acc, false, false);
|
hc::AmPointerInfo info(p, p, bufferSize, acc, false, false);
|
||||||
hc::am_memtracker_add(p, info);
|
hc::am_memtracker_add(p, info);
|
||||||
#else
|
|
||||||
hc::am_memtracker_add(p, bufferSize, acc, false);
|
|
||||||
#endif
|
|
||||||
}
|
}
|
||||||
} else if (addDir == Down) {
|
} else if (addDir == Down) {
|
||||||
for (char *p = basePtr+maxSize-bufferSize; p>=0; p-=bufferSize) {
|
for (char *p = basePtr+maxSize-bufferSize; p>=0; p-=bufferSize) {
|
||||||
#if USE_AV_COPY
|
|
||||||
hc::AmPointerInfo info(p, p, bufferSize, acc, false, false);
|
hc::AmPointerInfo info(p, p, bufferSize, acc, false, false);
|
||||||
hc::am_memtracker_add(p, info);
|
hc::am_memtracker_add(p, info);
|
||||||
#else
|
|
||||||
hc::am_memtracker_add(p, bufferSize, acc, false);
|
|
||||||
#endif
|
|
||||||
}
|
}
|
||||||
}
|
}
|
||||||
|
|
||||||
|
|||||||
@@ -36,7 +36,6 @@ THE SOFTWARE.
|
|||||||
#define USE_HCC_MEMTRACKER 0
|
#define USE_HCC_MEMTRACKER 0
|
||||||
#endif
|
#endif
|
||||||
|
|
||||||
#define USE_HSA_COPY 1
|
|
||||||
|
|
||||||
int elementSizes[] = {16, 1024,524288};
|
int elementSizes[] = {16, 1024,524288};
|
||||||
int nSizes = sizeof(elementSizes) / sizeof(int);
|
int nSizes = sizeof(elementSizes) / sizeof(int);
|
||||||
@@ -102,11 +101,8 @@ void runTest(bool stepAIsCopy, bool hostSync, hipStream_t gpu0Stream, hipStream_
|
|||||||
hipStream_t stepAStream = gpu0Stream;
|
hipStream_t stepAStream = gpu0Stream;
|
||||||
|
|
||||||
if (stepAIsCopy) {
|
if (stepAIsCopy) {
|
||||||
#ifdef USE_HSA_COPY
|
|
||||||
HIPCHECK(hipMemcpyAsync(dataGpu1, dataGpu0_0, sizeElements, hipMemcpyDeviceToDevice, stepAStream));
|
HIPCHECK(hipMemcpyAsync(dataGpu1, dataGpu0_0, sizeElements, hipMemcpyDeviceToDevice, stepAStream));
|
||||||
#endif
|
|
||||||
} else {
|
} else {
|
||||||
//assert(0); // not yet supported.
|
|
||||||
unsigned blocks = HipTest::setNumBlocks(blocksPerCU, threadsPerBlock, numElements);
|
unsigned blocks = HipTest::setNumBlocks(blocksPerCU, threadsPerBlock, numElements);
|
||||||
hipLaunchKernelGGL(memcpyIntKernel, dim3(blocks), dim3(threadsPerBlock), 0, gpu0Stream,
|
hipLaunchKernelGGL(memcpyIntKernel, dim3(blocks), dim3(threadsPerBlock), 0, gpu0Stream,
|
||||||
dataGpu0_0, dataGpu1, numElements);
|
dataGpu0_0, dataGpu1, numElements);
|
||||||
|
|||||||
Reference in New Issue
Block a user